@@ -31,13 +31,40 @@ int text_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data,
     MSA_UNUSED(cp);
     MSA_UNUSED(data_size);
 
-    *response = g_strdup(data);
-    while((tmp = strstr(*response, "<br>")) != NULL)
+    while((tmp = strstr(data, "<br>")) != NULL)
     {
         for(k = 0; k < 3; k++)
             *(tmp + k) = ' ';
         *(tmp + k) = '\n';
     }
+    tmp = NULL;
+/*
+FIXME
+replace & to &amp; in url
+
+&amp;
+&lt;
+&gt;
+&apos;
+&quot;
+&#x43E;
+*/
+    tmp = data;
+    while((tmp = strstr(tmp, "http")) != NULL)
+    {
+        while(*tmp != '<' && *tmp != '\0'){
+            if(*tmp == '&' && !g_str_has_prefix(tmp, "&amp;") 
+                           && !g_str_has_prefix(tmp, "&lt;")
+                           && !g_str_has_prefix(tmp, "&gt;")
+                           && !g_str_has_prefix(tmp, "&apos;")
+                           && !g_str_has_prefix(tmp, "&quot;")
+                           && !g_str_has_prefix(tmp, "&#x")){
+                *tmp = ' ';
+            }
+            tmp++;
+        }
+    }
+    *response = g_strdup(data);
     return 0;
 }
 #endif
@@ -81,6 +108,24 @@ int webauth_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* dat
 }
 #endif
 
+#ifdef NOT_USE_DEFAULT_WEBCAPTCHA_PARSER
+int webcaptcha_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
+{
+    if(data != NULL){
+        if(g_strcmp0(data, "closed") == 0){
+            *response = g_strdup(MSG_CAPT_ERROR);
+            return 1;
+        } else {
+            *response = g_strdup_printf("<response>%s</response>",data);
+            return 0;
+        }
+    } 
+    *response = g_strdup(MSG_CAPT_ERROR);
+    return 1;
+
+}
+#endif
+
 #ifdef NOT_USE_DEFAULT_PROCESS_URL
 void process_url(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
 {
